/*
 * Carta.java
 *
 * Created on 19/05/2011, 09:47:40
 * License: GPLv3
 */
package jogo;

import java.awt.Graphics;
import java.awt.Image;
import javax.swing.ImageIcon;
import javax.swing.JPanel;

/**
 * Classe para representar uma Carta de baralho sobre a mesa
 * 
 * @author Gustavo Paulo Medeiros da Silva, Murilo Bauer, Emerson Ribeiro de Mello
 */
public class Carta {

    private Image imagem;
    private String nome;
    private boolean cartaoponente_manilha; // false = minhas cartas, pode enviar / true = cartas oponente, nao pode enviar
    private boolean escolhida; //usado para o escolher a carta
    private int posicaoCarta; //pegar posicao das cartas; 
    private int x;
    private int y;
    private int largura;
    private int altura;
    private final static String caminhoImg = "resources/cartas/";

    //construtor das cartas de cada Jogador
    public Carta(String nomeArqImagem, int numCartas, int alt, int larg, String nome, boolean cartaOponenteManilha) {
        ImageIcon iicon = new ImageIcon(this.getClass().getResource("/" + caminhoImg + nomeArqImagem));
        this.nome = nome;
        this.imagem = iicon.getImage();
        this.largura = this.imagem.getWidth(null);
        this.altura = this.imagem.getHeight(null);
        this.escolhida = false;
        this.cartaoponente_manilha = cartaOponenteManilha;

        this.y = 0;
        if (!"fundocarta.png".equals(nomeArqImagem)) {
            this.y += 100;
        }
        this.posicaoCarta = numCartas;
        this.cartaoponente_manilha = cartaOponenteManilha;
        switch (numCartas) {

            case 0:
                this.posicaoCarta = 0;
                this.x = (larg / 2) - 140;
                this.y = (alt / 2) + 120;
                break;

            case 1:
                this.posicaoCarta = 1;
                this.x = (larg / 2) - 40;
                this.y = (alt / 2) + 120;
                break;

            case 2:
                this.posicaoCarta = 2;
                this.x = (larg / 2) + 60;
                this.y = (alt / 2) + 120;
                break;

            case 3:
                this.cartaoponente_manilha = true;
                this.posicaoCarta = 3;
                this.x = (larg / 2) + 160;
                this.y = (alt / 2) - 50;
                break;

            case 4:
                this.x = (larg / 2) + 60;
                this.y = (alt / 2) - 220 + this.y;
                break;

            case 5:
                this.x = (larg / 2) - 40;
                this.y = (alt / 2) - 220 + this.y;
                break;

            case 6:
                this.x = (larg / 2) - 140;
                this.y = (alt / 2) - 220 + this.y;
                break;
        }
    }

    /**
     * Atualiza as coordenadas X e Y da carta
     * @param nx - nova coordenada X
     * @param ny - nova coordenada Y
     */
    public boolean escolhida() {
        boolean enviar = true;
        if (this.cartaoponente_manilha == false) {
            if (this.escolhida == false) {
                this.y -= 100;
                this.cartaoponente_manilha = true; //nao pode mecher mais
                this.escolhida = true;
                enviar = true;  //se subir e mecher, envia
            }
        } else {
            enviar = false; //se ja mechido nao envia
        }
        return enviar;
    }

    /**
     * Verifica se as coordenadas do clique do mouse estão contidas dentro dos 
     * limites da carta
     * @param px -- coordenada X do clique
     * @param py -- coordenada Y do clique
     * @return true se o clique foi dentro da area da carta
     */
    public boolean clicouDentro(int px, int py) {
        return ((px > this.x && px < (this.x + largura))
                && (py > this.y && py < (this.y + altura))) ? true : false;
    }

    /**
     * Desenha a carta no JPanel pai.
     * @param g 
     * @param pai 
     */
    public void desenhar(Graphics g, JPanel pai) {
        Image i = this.imagem;
        g.drawImage(i, this.x, this.y, pai);
    }

    public String getNomeCarta() {
        return this.nome;
    }

    public int getPosicaoCarta() {
        return posicaoCarta;
    }

    public void mudaPosicao(int i) {
        this.x = 10;
        switch (i) {
            case 0:
                this.y = altura/2 - 40;
                break;
            case 1:
                this.y = altura/2 - 20;
                break;
            case 2:
                this.y = altura/2 + 80;
                break;
            case 3:
                this.y = altura/2 + 100;
                break;
            case 4:
                this.y = altura/2 + 200;
                break;
            case 5:
                this.y = altura/2 + 220;
                break;
        }
    }
}
