/*
 * Mesa.java
 *
 * Created on 19/05/2011, 09:47:40
 * License: GPLv3
 */
package jogo;

import java.awt.Graphics;
import java.util.ArrayList;

/**
 * Classe para representar a Mesa com as cartas
 * 
 * @author Gustavo Paulo Medeiros da Silva, Murilo Bauer, Emerson Ribeiro de Mello
 */
public class Mesa extends javax.swing.JPanel {

    private Principal pai;
    private ArrayList<Carta> baralho;
    private Carta cartaAMover; // Qual carta foi selecionada com o mouse

    /**
     * Construtor
     * @param aThis -- JFrame principal para permitir a mesa interagir com os atributos do pai
     * @param b  -- Baralho que foi criado no Principal
     */
    public Mesa(Principal aThis, ArrayList<Carta> b) {
        initComponents();
        this.pai = aThis;
        this.baralho = b;
    }

    @Override
    public void paint(Graphics g) {
        super.paint(g);
        // Percorre todo baralho e redesenha todas as cartas na mesa
        try {

            for (int i = 0; i < this.baralho.size(); i++) {
                this.baralho.get(i).desenhar(g, this);
            }
            g.dispose();
        } catch (Exception e) {
            System.err.println("OCORREU UM ERRO NA MESA!!! " + e);
        }
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        setBackground(new java.awt.Color(204, 204, 204));
        setCursor(new java.awt.Cursor(java.awt.Cursor.DEFAULT_CURSOR));
        addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                formMouseClicked(evt);
            }
            public void mousePressed(java.awt.event.MouseEvent evt) {
                formMousePressed(evt);
            }
            public void mouseReleased(java.awt.event.MouseEvent evt) {
                formMouseReleased(evt);
            }
        });
        addMouseMotionListener(new java.awt.event.MouseMotionAdapter() {
            public void mouseDragged(java.awt.event.MouseEvent evt) {
                formMouseDragged(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 508, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 403, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents

   private void formMouseClicked(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_formMouseClicked
       // Aconteceu um double click sobre uma carta, coloque para cima!
       if ((evt.getClickCount() > 1) && (this.acharCartaClicada(evt.getX(), evt.getY()))) {
           if (this.pai.getminhavez()) {
               if (this.cartaAMover.escolhida()) {
                   this.pai.enviarDadosCartas(cartaAMover.getNomeCarta(), cartaAMover.getPosicaoCarta());
                   this.repaint();
               }
           }
       }
   }//GEN-LAST:event_formMouseClicked

   private void formMousePressed(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_formMousePressed
       // O botão do mouse foi pressionado sobre uma carta?
       this.acharCartaClicada(evt.getX(), evt.getY());
   }//GEN-LAST:event_formMousePressed

   private void formMouseDragged(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_formMouseDragged
   }//GEN-LAST:event_formMouseDragged

   private void formMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_formMouseReleased
   }//GEN-LAST:event_formMouseReleased

    /**
     * Verifica se o clique do mouse foi sobre alguma carta na mesa
     * @param mX -- Coordenada X do clique 
     * @param mY -- Coordenada Y do clique
     * @return true se realmente clicou sobre uma carta, false caso contrário
     */
    public int getAltura() {
        return this.getHeight();
    }

    public int getLargura() {
        return this.getWidth();
    }

    private boolean acharCartaClicada(int mX, int mY) {
        for (Carta carta : this.baralho) {
            if (carta.clicouDentro(mX, mY)) {
                this.cartaAMover = carta;
                return true;
            }
        }
        return false;
    }
    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
}
